/***
The Macros in this file run CZ (step 1 of 2) and CTY (direct estimation) regressions
to identify the causal effects of growing up in each geography in the US for
The Impacts of Neighborhoods on Intergenerational Mobility II

Note: The microdata which is an input to these macros is not publicly available
***/

/*
List of Macros:
	1)  make_beta_ijs 
	2)  make_beta_ijs_bs
	3)  gary
	4)  odfe
	5)  reshape
	6)  reshapecov
	7)  make_beta_js
	7) run_beta_ijs_base
	8) run_beta_js_base
*/


/*
Variable Dictionary:
	Ageatmove: child age in the year of the move
	cohort_s: birth cohort - 1980
	cohort_s_2: cohort_s^2
	cohort_s_par_rank_n: cohort_s * par_rank_n
	cohort_s_2_par_rank_n: cohort_s_2 * par_rank_n
	kid_fam_inc: Average pre-tax household income at age 26, measured as AGI for tax filers and using information returns for non-filers.
	par_fam_inc_1996_2000: Average pre-tax household income from 1996-2000, measured as AGI for tax filers and using information returns for non-filers.
	kid_rank: rank of kid_fam_inc
	par_rank_n: rank of par_fam_inc_1996_2000
	par_cz_dest: parent commuting zone after a move
	par_cz_orig: parent commuting zone before a move
		We define moves by comparing subsequent years of parent geographies for each year set of years in our data. A given child moves when the parent geographies are both not missing
		and not equal in subsequent years.
*/

*-----------------------------------------------------------------------------------------------;
* Macro: make_beta_ijs 
* Purpose: 
*	- Estimates pairwise origin-destination exposure effects. 
*	- Each invocation of the macro produces a single output file containing regression coeffs.
*		representing the causal exposure effects of a year in each dest geo. relative to the origin geo
*	- The output file has one line per origin-destination pair. 
* Arguments: 
*	- var   : outcome variable
*	- name  : name for the particular specification and outputs
*	- geo   : geographic level of analysis - primarily CZ
*	- cntrl : list of control variables
*	- w     : where condition subsetting the one-time moves file (baseline w=age_at_move<=23) 
*-----------------------------------------------------------------------------------------------;

%macro make_beta_ijs(var, name, geo, cntrl, w);
	%let prog = beta; %let v = v12;
	
	* 1) READ IN DATA;
		* Restrict to where condition and !missing(depvar);
		proc sql;
			create table beta.&prog._&v._&geo.&name. as
			select * from beta.&prog._&v._&geo. (where = (&w. & ~missing(&var.)))
			group by par_&geo._orig, par_&geo._dest
			order by par_&geo._orig, par_&geo._dest; 
		quit;

	* 2) Estimate OD regression;
		proc reg data = beta.&prog._&v._&geo.&name. outest = templog tableout covout edf noprint;
			by par_&geo._orig par_&geo._dest;
			model &var. = par_rank_n ageatmove ageatmove_par_rank_n &cntrl.;
		run;

	* 3) Keep relevant outputs and create n_od count;
	data templog;
		set templog (where=(_type_="PARMS" | _type_="STDERR" | _type_="COV" ));
		by par_&geo._orig par_&geo._dest;
		retain n_od;
		if first.par_&geo._dest then n_od = .;
		if _type_="PARMS" then n_od = sum(_p_, _edf_);
	run;

	* 4) Reshape output;
	proc sql;
		create table beta.&prog._&v._&geo.&name._um as 
		select A.par_&geo._orig, A.par_&geo._dest, A.n_od, A.ageatmove, A.ageatmove_par_rank_n, 
			   B.ageatmove as se_ageatmove, B.ageatmove_par_rank_n as se_ageatmove_par_rank_n
		from templog (where = (_TYPE_ = "PARMS")) as A left join templog (where = (_TYPE_ = "STDERR")) as B
		on A.par_&geo._orig = B.par_&geo._orig and A.par_&geo._dest = B.par_&geo._dest;
	quit;
	proc sql;
		create table beta.&prog._&v._&geo.&name._um as 
		select A.*, B.ageatmove_par_rank_n as cov 
		from beta.&prog._&v._&geo.&name._um as A left join  templog (where = (_TYPE_ = "COV" and _NAME_ = "ageatmove")) as B
		on A.par_&geo._orig = B.par_&geo._orig and A.par_&geo._dest = B.par_&geo._dest;
	quit;

	* 5) Mask output and convert to Stata for use on the outside;
	data beta.&prog._&v._&geo.&name.; set beta.&prog._&v._&geo.&name._um (where = (n_od >= 25)); run;

	%sas2stata2(beta.&prog._&v._&geo.&name.);
%mend;

*-----------------------------------------------------------------------------------------------;
* Macro: make_beta_ijs_bs
* Purpose: 
*	- Estimates BOOTSTRAPPED pairwise origin-destination exposure effects. 
*	- Each invocation of the macro produces a single output file containing regression coeffs (from each bs iteration)
*		representing the causal exposure effects of a year in each dest geo. instead of origin geo
*	- The output file has one line per origin-destination pair. 
*   - Number of bootstrap iterations governed by parameter NUM.
* Arguments: 
*	- var   : outcome variable
*	- name  : name for the particular specification and is used to name outputs
*	- geo   : geographic level of analysis - usually cz or cty
*   - num   : number of bootstrap repetitions
*	- cntrl : list of control variables
*	- w     : where condition subsetting the one-time moves file (baseline w=age_at_move<=23) 
*-----------------------------------------------------------------------------------------------;

%macro make_beta_ijs_bs(var, name, geo, num, cntrl, w);
	%let prog = beta; %let v = v12;

	* 1) Restrict to where condition and !missing(depvar);
	proc sql;
		create table beta.&prog._&v._bs_&geo.&name. as
		select *, count(*) as n_od from beta.&prog._&v._&geo. (where = (&w. & ~missing(&var.)))
		group by par_&geo._orig, par_&geo._dest
		order by par_&geo._orig, par_&geo._dest; 
	quit;
	%do i = 1 %to &num.; 
		* 2) Select random sample of data with replacement from n_od >= 25 population, then implement Beta_ij regression and store output as in make_beta_ijs;
		proc surveyselect data = beta.&prog._&v._bs_&geo.&name. (where = (n_od >= 25)) outhits out = temp_bs method = urs samprate = 1 seed = &i.; run;

		* 3) Perform by orig-dest regression;
		proc reg data = temp_bs outest = templog tableout covout edf noprint;
			by par_&geo._orig par_&geo._dest;
			model &var. = par_rank_n ageatmove ageatmove_par_rank_n &cntrl.;
		run;

		* 4) format and reshape output;
		data templog;
			set templog (where=(_type_="PARMS" | _type_="STDERR" | _type_="COV" ));
			by par_&geo._orig par_&geo._dest;
			retain n_od_&i.;
			if first.par_&geo._dest then n_od_&i. = .;
			if _type_="PARMS" then n_od_&i. = sum(_p_, _edf_);
		run;
		proc sql;
			create table temp_out as 
			select A.par_&geo._orig, A.par_&geo._dest, A.n_od_&i., A.ageatmove as ageatmove_&i., A.ageatmove_par_rank_n as ageatmove_par_rank_n_&i., 
				   B.ageatmove as se_ageatmove_&i., B.ageatmove_par_rank_n as se_ageatmove_par_rank_n_&i.
			from templog (where = (_TYPE_ = "PARMS")) as A left join templog (where = (_TYPE_ = "STDERR")) as B
			on A.par_&geo._orig = B.par_&geo._orig and A.par_&geo._dest = B.par_&geo._dest;
		quit;
		proc sql;
			create table temp_out as 
			select A.*, B.ageatmove_par_rank_n as cov_&i. 
			from temp_out as A left join templog (where = (_TYPE_ = "COV" and _NAME_ = "ageatmove")) as B
			on A.par_&geo._orig = B.par_&geo._orig and A.par_&geo._dest = B.par_&geo._dest;
		quit;

		* 5) Mask and store output;
		data temp_out; set temp_out (where = ( n_od_&i. >= 25)); run;

		%if &i. = 1 %then %do; data boot2.&prog._&v._bs_&geo.&name.; set temp_out; run; %end;
		%if &i. > 1 %then %do; 
			proc sql;
				create table boot2.&prog._&v._bs_&geo.&name. as
				select A.*, B.* from boot2.&prog._&v._bs_&geo.&name. as A full join temp_out as B
				on A.par_&geo._orig = B.par_&geo._orig and A.par_&geo._dest = B.par_&geo._dest;
			quit;	
		%end;
		data boot2.&prog._&v._bs_&geo.&name.; set boot2.&prog._&v._bs_&geo.&name. (where = (~missing(par_&geo._orig) and ~missing(par_&geo._dest))); run;
	%end;
	
	%sas2stata2(boot2.&prog._&v._bs_&geo.&name.);
%mend;

*-----------------------------------------------------------------------------------------------;
* Helper macro for make_beta_j(): gary
* Purpose:
* 	- Implements the microdata version of "Gary's Matrix" to identify pairwise PEs by county. 
*	- For pairwise PE estimates produced by %make_beta_ijs, Gary's Matrix is implemented on 
*		the outside (so estimation of causal effects by CZ is a two-step procedure). 
*	- For county level causal effects, we combine both steps by implementing Garys Matrix 
*		directly on individual-level data within each CZ. 
*	- Populates indicators and interactions for every cty in odlist (4*n_od new vars per obs).
*		- If a county in odlist is your destination (origin), indicator set to 1 (-1), else 0.
*   	- The interactions with each county indicator and age at move, parent rank, and the 
*			interaction of age at move and parent rank are also contructed. 
* Arguments:
* 	- odlist : List of counties within a CZ that are origins/destinations of families in sample
*   - n_od   : Length of odlist
*-----------------------------------------------------------------------------------------------;

%macro gary(odlist, n_od);
	%do j = 1 %to &n_od.;
		%let geo_od = %scan(&odlist., &j.);
		length x_&geo_od. x_&geo_od._p  x_&geo_od._a  x_&geo_od._ap 8;	
		x_&geo_od. = 0;
		if par_cty_orig = &geo_od. then x_&geo_od. = -1;
		if par_cty_dest = &geo_od. then x_&geo_od. =  1;
		x_&geo_od._p  = x_&geo_od. * par_rank_n;
		x_&geo_od._a  = x_&geo_od. * ageatmove;
		x_&geo_od._ap = x_&geo_od. * ageatmove_par_rank_n;
	%end;
%mend;

*-----------------------------------------------------------------------------------------------;
* Helper macro for make_beta_j(): odfe
* Purpose:
*	- Constructs origin-by-destination fixed effects.
*	- Indicators are constructed for each orig-dest pair in the sample, as well as the 
*		interaction of each indicator and parent rank (2*n_c new variables). 
*	- New variables are all named od_* so that they may all be referrenced with od_:.
* Arguments:
*	- clist	: a list of all origin-destination pairs (clist) 
*	- n_c	: number of those pairs (n_c). 
*-----------------------------------------------------------------------------------------------;

%macro odfe(clist, n_c);
	%do k = 1 %to &n_c.;
		%let c = %scan(&clist., &k.);
		length od_&c. od_p_&c. 8;	
		od_&c. = 0;
		if od = &c. then od_&c. = 1;
		od_p_&c. = od_&c. * par_rank_n;
	%end;
%mend;

*-----------------------------------------------------------------------------------------------;
* Helper macro for make_beta_j(): reshape 
* Purpose:
*	- Reshapes parameter estimates and standard errors into a useable form. 
* Arguments:
* 	- odlist : List of counties within a CZ that are origins/destinations of families in sample
*   - n_od   : Length of odlist
*-----------------------------------------------------------------------------------------------;

%macro reshape(odlist, n_od);
	%do l = 1 %to &n_od.;
		%let geo_od = %scan(&odlist., &l.);
		cty                  = &geo_od.;
		ageatmove            = x_&geo_od._a;
		ageatmove_par_rank_n = x_&geo_od._ap;
		output;
	%end;
%mend;

*-----------------------------------------------------------------------------------------------;
* Helper macro for make_beta_j(): reshapecov
* Purpose:
*	- Reshapes estimates of the covariance of estimated parameters for each county.
* Arguments:
* 	- odlist : List of counties within a CZ that are origins/destinations of families in sample
*   - n_od   : Length of odlist
*-----------------------------------------------------------------------------------------------;

%macro reshapecov(odlist, n_od);
	%do m = 1 %to &n_od.;
		%let geo_od = %scan(&odlist., &m.);
		if cty = &geo_od. then cov = x_&geo_od._a;
	%end;
%mend;


*-----------------------------------------------------------------------------------------------;
* Macro: make_beta_js
* Purpose:
*	- Estimates county-level exposure effects from cty within cz movers in the micro-data.
*	- Each invocation of the macro produces a single output file containing regression coeffs.
*		representing the causal exposure effects of spending an extra year living in a 
*		particular county during childhood, outputting one line per county.
*	- Unlike make_beta_ijs, this macro only produces county-level estimates (not orig-dest pair estimates).
*		- You need to specify the geography WITHIN which the estimates are produced (usually CZ, sometimes CSA).
		  For example: choose CZ, then we make cty estimates for cty w/in cz movers.
*	- The estimates produced here are interpreted as deviations from the index geography avg, 
*		and estimates are constrained to sum (population weighted) to zero.
* Arguments:
*	- var   : outcome variable
*	- name  : name for the particular specification and is used to name outputs
*	- geo   : index geography - usually cz but sometimes csa
*	- cntrl : list of control variables
*	- w     : where condition subsetting the one-time moves file (baseline w=age_at_move<=23) 
*-----------------------------------------------------------------------------------------------;

%macro make_beta_js(var, name, geo, cntrl, w);
	%let prog = betaj; %let v = v7;
	%global geolist; %global n_geo;


	* 1) Read in data and store each index geo (cz) in a list;
	%if &name. ~= kr26_pmi_cc2 %then %do;
		data betaj.&prog._&v._&geo.cty_&name.; set betaj.&prog._&v._&geo.cty (where = (&w. & ~missing(&var.))); run;
		proc sql; create table temp_geo as select distinct &geo. from betaj.&prog._&v._&geo.cty_&name.; quit;
		proc sql; select &geo. into : geolist separated by ' ' from temp_geo; quit;
		proc sql; select count(*) into : n_geo from temp_geo; quit;
		%put &geolist. &n_geo.;
	%end;

	* Iterate through each index geography;
	%do i = 1 %to &n_geo.;
		%let geo_c = %scan(&geolist., &i.); %put &geo_c. ;

		* 2.1) Restrict to movers within the index geography;
		data temp; set  betaj.&prog._&v._&geo.cty_&name. (where = (&geo. = &geo_c.)); run;
		proc sort data = temp; by od; quit;
		
		%global odlist; %global n_od; %global clist; %global n_c;
		* 2.2) populate list of ctys within the index geography (odlist);
		proc sql; create table temp_o as select distinct par_cty_orig as cty from temp; quit;
		proc sql; create table temp_d as select distinct par_cty_dest as cty from temp; quit;
		data temp_od_dup; set temp_o temp_d; run;
		proc sql; create table temp_od as select distinct cty from temp_od_dup; quit;
		proc sql; select cty into : odlist separated by ' ' from temp_od; quit;
		proc sql; select count(*) into : n_od from temp_od; quit;
		* 2.3) Create list of distinct cty origin destination pairs within index geography (clist);
		proc sql; create table temp_c as select distinct od from temp; quit;
		data temp_c; set temp_c; id = _N_; run;
		proc sql; create table temp as select A.*, B.* from temp as A left join temp_c as B on A.od = B.od; quit;
		data temp (drop = id); set temp (drop = od); od = id; run;
		proc sql; select id into : clist separated by ' ' from temp_c; quit;
		proc sql; select count(*) into : n_c from temp_c; quit;
		%put &n_od. &n_c.;

		* 3) Call helper macros to create Gary's matrix and orig-dest fixed effects;
		data gary; set temp; 
			%gary(&odlist., &n_od.); 
			%odfe(&clist.,  &n_c. ); 
		run;
		data gary; set gary; &var. = &var. * 100; run; * re-normlization for precise estimation of parameters;
	
		* 4a) Create population restrictions. We want the population-weighted sum of all x_a_* variables 
			and the population-weighted sum of all x_ap_* variables to be zero. This is accomplished 
			by applying two restrictions in the form of linear combinations to the estimation of the
			regression below, practically accomplished by building two strings. We first insheet a file 
			containing the population of each county in the US;
		data betaj.cty_pop2;
			infile "movers/csv/cty_pop.csv" dlm='2C0D'x dsd missover lrecl=10000 firstobs = 2;
			input cty pop;
		run;
		* 4b) Next, we initialize the restriction macros r1 and r2 with the population value for the first 
			county in odlist. We store the value of pop, then trim it. We then initialize the r1 and r2 macros using the 
			value of pop and the FIPS number of the first county in odlist (stored in geo_od). We then
			successively update the restriction macros for each additional geography in odlist;

		%let geo_od = %scan(&odlist., 1);
		data _null_; set betaj.cty_pop2 (where = (cty = &geo_od.)); pop_2 = trimn(pop); call symput("pop_tmp", pop_2); run;
		%let pop = %trim(&pop_tmp.);
		%let r1 = %str(&pop.*x_&geo_od._a); %let r2 = %str(&pop.*x_&geo_od._ap);
		%do p = 2 %to &n_od.;
			%let geo_od = %scan(&odlist., &p.);	
			data _null_; set betaj.cty_pop2 (where = (cty = &geo_od.)); pop_2 = trimn(pop); call symput("pop_tmp", pop_2); run;
			%let pop = %trim(&pop_tmp.); 
			%let r1 = %str(&r1.+&pop.*x_&geo_od._a); 
			%let r2 = %str(&r2.+&pop.*x_&geo_od._ap); 
		%end;

		* 5) Estimate causal exposure effects of counties within index geographies by regressing
			outcome (var) on the Gary's Matrix variables (x_:), origin-destination fixed effects 
			(od_:), and controls (&cntrl.), manually dropping the grand intercept and applying
			the restrictions r1 and r2. ;
		proc reg data = gary outest = templog tableout covout;
			model &var. = x_: od_: &cntrl. / noint;
			restrict &r1.;
			restrict &r2.;
		run;

		* 6) Reshape, format and mask output;
		data ests		 (drop =  _TYPE_ x_:);
			set templog (where = (_TYPE_ = "PARMS")
					      keep =  _TYPE_ x_:);
			length &geo. cty ageatmove ageatmove_par_rank_n 8;
			&geo. = &geo_c.;
			%reshape(&odlist., &n_od.);
		run;
		data stderrs     (drop =  _TYPE_ x_:);
			set templog (where = (_TYPE_ = "STDERR")
						  keep =  _TYPE_ x_:);
			length cty ageatmove ageatmove_par_rank_n 8;
			%reshape(&odlist., &n_od.);
		run;
		data cov         (drop =  _TYPE_ _NAME_ x_:);
			set templog (where = (_TYPE_ = "COV" and substrn(_NAME_, 1, 2) = "x_" and scan(_NAME_, 3, '_') = "ap")
					      keep =  _TYPE_ _NAME_ x_:); 
			length cty cov 8;
			cty = scan(_NAME_, 2, '_');
			%reshapecov(&odlist., &n_od.);
		run;
		proc sql; 
			create table temp_out as select A.*, B.ageatmove as se_ageatmove, B.ageatmove_par_rank_n as se_ageatmove_par_rank_n 
			from ests as A left join stderrs as B on A.cty = B.cty; 
		quit;
		proc sql;
			create table temp_out as select A.*, B.cov from temp_out as A left join cov as B on A.cty = B.cty;
		quit;
		data temp_out; set temp_out (where = (se_ageatmove ~= 0 and se_ageatmove_par_rank_n ~= 0)); run;

		* 7) Append data from sets of ctys w/in czs;	
		%if &i. = 1 %then %do; data betaj.&prog._&v._cty_&geo._&name.; set temp_out; run; %end;
		%if &i. > 1 %then %do; data betaj.&prog._&v._cty_&geo._&name.; set betaj.&prog._&v._cty_&geo._&name. temp_out; run; %end;
	%end;	
	%sas2stata2(betaj.&prog._&v._cty_&geo._&name.);
%mend;


*-----------------------------------------------------------------------------------------------;
* Macro: run_beta_ijs_base
* Purpose:
	Run beta_ij baseline kr26 specifications
* Arguments:
*	- geo   : estimate place effects at this geography: cz
*	- var   : outcome variable: kid_rank
*	- name  : name of specification which corresponds to outcome variable
*	- age   : estimate place effects using movers whose age at move <= this age cutoff
*-----------------------------------------------------------------------------------------------;

%macro run_beta_ijs_base(geo, var, name, age);
	* (1) KR26 Baseline Quadratic cohort control betas;
	* (1)  ; %make_beta_ijs(&var., &name._cc2, &geo., cohort_s cohort_s_par_rank_n cohort_s_2 cohort_s_2_par_rank_n, w=ageatmove <= &age.);
%mend;
%run_beta_ijs_base(cz, kid_rank, kr26, 23);


%macro run_beta_js_base(geo, var, name, age);
	* (1) KR26 Baseline Quadratic cohort control betas;
	* (1) ; %make_beta_js(&var., &name._cc2,     &geo., 	cohort_s cohort_s_par_rank_n cohort_s_2 cohort_s_2_par_rank_n															, w=ageatmove <= &age.);
%mend;
%run_beta_js_base(cz, kid_rank, kr26, 23);

